@@ -20,6 +20,9 @@ from multiprocessing import Pool
 import django
 import os
 
+MODO = os.environ.get('MODE')
+os.environ['DJANGO_SETTINGS_MODULE'] = f'dj_collector.settings.{MODO}'
+
 django.setup()
 
 from apps.station.models import InstallationEndPoint
